feast.serving package
=====================

Submodules
----------

feast.serving.ServingService\_pb2 module
----------------------------------------

.. automodule:: feast.serving.ServingService_pb2
   :members:
   :undoc-members:
   :show-inheritance:

feast.serving.ServingService\_pb2\_grpc module
----------------------------------------------

.. automodule:: feast.serving.ServingService_pb2_grpc
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: feast.serving
   :members:
   :undoc-members:
   :show-inheritance:
